// FIXME - this probably belongs somewhere else!
package gnu.mapping;
import java.io.PrintWriter;

public interface Printable {
   void print(PrintWriter ps);
}
